@@ -7,8 +7,6 @@
  *
  * This file contains handler for status and error pipes of GPG process.
  *
- * PHP version 5
- *
  * LICENSE:
  *
  * This library is free software; you can redistribute it and/or modify
@@ -46,8 +44,6 @@ require_once 'Crypt/GPG/Exceptions.php';
  */
 require_once 'Crypt/GPG/Signature.php';
 
-// {{{ class Crypt_GPG_ProcessHandler
-
 /**
  * Status/Error handler for GPG process pipes.
  *
@@ -66,8 +62,6 @@ require_once 'Crypt/GPG/Signature.php';
  */
 class Crypt_GPG_ProcessHandler
 {
-    // {{{ protected class properties
-
     /**
      * Engine used to control the GPG subprocess
      *
@@ -118,9 +112,6 @@ class Crypt_GPG_ProcessHandler
      */
     protected $operationArg = null;
 
-    // }}}
-    // {{{ __construct()
-
     /**
      * Creates a new instance
      *
@@ -131,9 +122,6 @@ class Crypt_GPG_ProcessHandler
         $this->engine = $engine;
     }
 
-    // }}}
-    // {{{ setOperation()
-
     /**
      * Sets the operation that is being performed by the engine.
      *
@@ -172,9 +160,6 @@ class Crypt_GPG_ProcessHandler
         $this->data['Warnings'] = array();
     }
 
-    // }}}
-    // {{{ handleStatus()
-
     /**
      * Handles error values in the status output from GPG
      *
@@ -266,7 +251,7 @@ class Crypt_GPG_ProcessHandler
             // remember the user id for pretty exception messages
             // GnuPG 2.1.15 gives me: "USERID_HINT 0000000000000000 [?]"
             $keyId = $tokens[1];
-            if (strcspn($keyId, '0')) {
+            if (preg_match('/[1-9A-F]/', $keyId)) {
                 $username = implode(' ', array_splice($tokens, 2));
                 $this->data['BadPassphrases'][$keyId] = $username;
             }
@@ -456,9 +441,6 @@ class Crypt_GPG_ProcessHandler
         }
     }
 
-    // }}}
-    // {{{ handleError()
-
     /**
      * Handles error values in the error output from GPG
      *
@@ -539,9 +521,6 @@ class Crypt_GPG_ProcessHandler
         }
     }
 
-    // }}}
-    // {{{ throwException()
-
     /**
      * On error throws exception
      *
@@ -771,9 +750,6 @@ class Crypt_GPG_ProcessHandler
         }
     }
 
-    // }}}
-    // {{{ throwException()
-
     /**
      * Check exit code of the GPG operation.
      *
@@ -803,20 +779,17 @@ class Crypt_GPG_ProcessHandler
         return Crypt_GPG::ERROR_UNKNOWN;
     }
 
-    // }}}
-    // {{{ getData()
-
     /**
      * Get data from the last process execution.
      *
      * @param string $name Data element name:
-     *               - SigCreated: The last SIG_CREATED status.
-     *               - KeyConsidered: The last KEY_CONSIDERED status identifier.
-     *               - KeyCreated: The KEY_CREATED status (for specified Handle).
-     *               - Signatures: Signatures data from verification process.
-     *               - LineNumber: Number of the gen-key error line.
-     *               - Import: Result of IMPORT_OK/IMPORT_RES
-     *               - Warnings: An array of all collected GnuPG warnings
+     *                     - SigCreated: The last SIG_CREATED status.
+     *                     - KeyConsidered: The last KEY_CONSIDERED status identifier.
+     *                     - KeyCreated: The KEY_CREATED status (for specified Handle).
+     *                     - Signatures: Signatures data from verification process.
+     *                     - LineNumber: Number of the gen-key error line.
+     *                     - Import: Result of IMPORT_OK/IMPORT_RES
+     *                     - Warnings: An array of all collected GnuPG warnings
      *
      * @return mixed
      */
@@ -825,20 +798,17 @@ class Crypt_GPG_ProcessHandler
         return isset($this->data[$name]) ? $this->data[$name] : null;
     }
 
-    // }}}
-    // {{{ setData()
-
     /**
      * Set data for the process execution.
      *
      * @param string $name  Data element name:
-     *               - Handle: The unique key handle used by this handler
-     *                         The key handle is used to track GPG status output
-     *                         for a particular key on --gen-key command before
-     *                         the key has its own identifier.
-     *               - IgnoreVerifyErrors: Do not throw exceptions
-     *                         when signature verification failes because
-     *                         of a missing public key.
+     *                      - Handle: The unique key handle used by this handler
+     *                      The key handle is used to track GPG status output
+     *                      for a particular key on --gen-key command before
+     *                      the key has its own identifier.
+     *                      - IgnoreVerifyErrors: Do not throw exceptions
+     *                      when signature verification failes because
+     *                      of a missing public key.
      * @param mixed  $value Data element value
      *
      * @return void
@@ -856,9 +826,6 @@ class Crypt_GPG_ProcessHandler
         }
     }
 
-    // }}}
-    // {{{ setData()
-
     /**
      * Create Crypt_GPG_BadPassphraseException from operation data.
      *
@@ -896,9 +863,6 @@ class Crypt_GPG_ProcessHandler
         );
     }
 
-    // }}}
-    // {{{ getPin()
-
     /**
      * Get registered passphrase for specified key.
      *
@@ -933,10 +897,4 @@ class Crypt_GPG_ProcessHandler
 
         return $passphrase;
     }
-
-    // }}}
 }
-
-// }}}
-
-?>
