@@ -60,39 +60,30 @@ require_once 'Crypt/GPG/Exceptions.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class ExceptionsTestCase extends Crypt_GPG_TestCase
+class ExceptionsTest extends Crypt_GPG_TestCase
 {
-    // exception
-    // {{{ testException
-
     /**
      * @group exception
-     * @expectedException Crypt_GPG_Exception
-     * @expectedExceptionMessage test exception
      */
     public function testException()
     {
+        $this->expectException('Crypt_GPG_Exception');
+        $this->expectExceptionMessage('test exception');
+
         throw new Crypt_GPG_Exception('test exception');
     }
 
-    // }}}
-
-    // file exception
-    // {{{ testFileException
-
     /**
      * @group file-exception
-     * @expectedException Crypt_GPG_FileException
-     * @expectedExceptionMessage test exception
      */
     public function testFileException()
     {
+        $this->expectException('Crypt_GPG_FileException');
+        $this->expectExceptionMessage('test exception');
+
         throw new Crypt_GPG_FileException('test exception');
     }
 
-    // }}}
-    // {{{ testFileException_getFilename()
-
     /**
      * @group file-exception
      */
@@ -104,24 +95,17 @@ class ExceptionsTestCase extends Crypt_GPG_TestCase
         $this->assertEquals('test-filename.php', $e->getFilename());
     }
 
-    // }}}
-
-    // open subprocess exception
-    // {{{ testOpenSubprocessException
-
     /**
      * @group open-subprocess-exception
-     * @expectedException Crypt_GPG_OpenSubprocessException
-     * @expectedExceptionMessage test exception
      */
     public function testOpenSubprocessException()
     {
+        $this->expectException('Crypt_GPG_OpenSubprocessException');
+        $this->expectExceptionMessage('test exception');
+
         throw new Crypt_GPG_OpenSubprocessException('test exception');
     }
 
-    // }}}
-    // {{{ testOpenSubprocessException_getCommand()
-
     /**
      * @group open-subprocess-exception
      */
@@ -133,24 +117,17 @@ class ExceptionsTestCase extends Crypt_GPG_TestCase
         $this->assertEquals('gpg --verify', $e->getCommand());
     }
 
-    // }}}
-
-    // invalid operation exception
-    // {{{ testInvalidOperationException
-
     /**
      * @group invalid-operation-exception
-     * @expectedException Crypt_GPG_InvalidOperationException
-     * @expectedExceptionMessage test exception
      */
     public function testInvalidOperationException()
     {
+        $this->expectException('Crypt_GPG_InvalidOperationException');
+        $this->expectExceptionMessage('test exception');
+
         throw new Crypt_GPG_InvalidOperationException('test exception');
     }
 
-    // }}}
-    // {{{ testInvalidOperationException_getOperation()
-
     /**
      * @group invalid-operation-exception
      */
@@ -162,24 +139,17 @@ class ExceptionsTestCase extends Crypt_GPG_TestCase
         $this->assertEquals('--verify', $e->getOperation());
     }
 
-    // }}}
-
-    // key not found exception
-    // {{{ testKeyNotFoundException
-
     /**
      * @group key-not-found-exception
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     * @expectedExceptionMessage test exception
      */
     public function testKeyNotFoundException()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+        $this->expectExceptionMessage('test exception');
+
         throw new Crypt_GPG_KeyNotFoundException('test exception');
     }
 
-    // }}}
-    // {{{ testKeyNotFoundException_getKeyId()
-
     /**
      * @group key-not-found-exception
      */
@@ -191,39 +161,28 @@ class ExceptionsTestCase extends Crypt_GPG_TestCase
         $this->assertEquals('9F93F9116728EF12', $e->getKeyId());
     }
 
-    // }}}
-
-    // no data exception
-    // {{{ testNoDataException
-
     /**
      * @group no-data-exception
-     * @expectedException Crypt_GPG_NoDataException
-     * @expectedExceptionMessage test exception
      */
     public function testNoDataException()
     {
+        $this->expectException('Crypt_GPG_NoDataException');
+        $this->expectExceptionMessage('test exception');
+
         throw new Crypt_GPG_NoDataException('test exception');
     }
 
-    // }}}
-
-    // bad passphrase exception
-    // {{{ testBadPassphraseException
-
     /**
      * @group bad-passphrase-exception
-     * @expectedException Crypt_GPG_BadPassphraseException
-     * @expectedExceptionMessage test exception
      */
     public function testBadPassphraseException()
     {
+        $this->expectException('Crypt_GPG_BadPassphraseException');
+        $this->expectExceptionMessage('test exception');
+
         throw new Crypt_GPG_BadPassphraseException('test exception');
     }
 
-    // }}}
-    // {{{ testBadPassphraseException_getBadPassphrases()
-
     /**
      * @group bad-passphrase-exception
      */
@@ -240,9 +199,6 @@ class ExceptionsTestCase extends Crypt_GPG_TestCase
         $this->assertContains('9F93F9116728EF12', $keyIds);
     }
 
-    // }}}
-    // {{{ testBadPassphraseException_getMissingPassphrase()
-
     /**
      * @group bad-passphrase-exception
      */
@@ -259,24 +215,17 @@ class ExceptionsTestCase extends Crypt_GPG_TestCase
         $this->assertContains('9F93F9116728EF12', $keyIds);
     }
 
-    // }}}
-
-    // delete private key exception
-    // {{{ testDeletePrivateKeyException
-
     /**
      * @group delete-private-key-exception
-     * @expectedException Crypt_GPG_DeletePrivateKeyException
-     * @expectedExceptionMessage test exception
      */
     public function testDeletePrivateKeyException()
     {
+        $this->expectException('Crypt_GPG_DeletePrivateKeyException');
+        $this->expectExceptionMessage('test exception');
+
         throw new Crypt_GPG_DeletePrivateKeyException('test exception');
     }
 
-    // }}}
-    // {{{ testDeletePrivateKeyException_getKeyId()
-
     /**
      * @group delete-private-key-exception
      */
@@ -287,8 +236,4 @@ class ExceptionsTestCase extends Crypt_GPG_TestCase
 
         $this->assertEquals('9F93F9116728EF12', $e->getKeyId());
     }
-
-    // }}}
 }
-
-?>
