@@ -55,10 +55,8 @@ require_once 'TestCase.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class GetFingerprintTestCase extends Crypt_GPG_TestCase
+class GetFingerprintTest extends Crypt_GPG_TestCase
 {
-    // {{{ testGetFingerprint()
-
     /**
      * @group get-fingerprint
      */
@@ -70,9 +68,6 @@ class GetFingerprintTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedFingerprint, $fingerprint);
     }
 
-    // }}}
-    // {{{ testGetFingerprintNull()
-
     /**
      * @group get-fingerprint
      */
@@ -83,9 +78,6 @@ class GetFingerprintTestCase extends Crypt_GPG_TestCase
         $this->assertNull($fingerprint);
     }
 
-    // }}}
-    // {{{ testGetFingerprintX509()
-
     /**
      * @group get-fingerprint
      */
@@ -101,9 +93,6 @@ class GetFingerprintTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedFingerprint, $fingerprint);
     }
 
-    // }}}
-    // {{{ testGetFingerprintCanonical()
-
     /**
      * @group get-fingerprint
      */
@@ -118,8 +107,4 @@ class GetFingerprintTestCase extends Crypt_GPG_TestCase
 
         $this->assertEquals($expectedFingerprint, $fingerprint);
     }
-
-    // }}}
 }
-
-?>
