@@ -60,11 +60,8 @@ require_once 'Crypt/GPG/Signature.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class SignatureTestCase extends Crypt_GPG_TestCase
+class SignatureTest extends Crypt_GPG_TestCase
 {
-    // construct
-    // {{{ testConstructFromSignature()
-
     /**
      * @group construct
      */
@@ -85,9 +82,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedSignature, $signature);
     }
 
-    // }}}
-    // {{{ testConstructFromArray()
-
     /**
      * @group construct
      */
@@ -120,11 +114,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
             strval($signature->getUserId()));
     }
 
-    // }}}
-
-    // accessors
-    // {{{ testGetId()
-
     /**
      * @group accessors
      */
@@ -142,9 +131,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals('KuhELanvhPRXozEjFWb2mam1q20', $signature->getId());
     }
 
-    // }}}
-    // {{{ testGetKeyFingerprint()
-
     /**
      * @group accessors
      */
@@ -163,9 +149,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
             $signature->getKeyFingerprint());
     }
 
-    // }}}
-    // {{{ testGetKeyId()
-
     /**
      * @group accessors
      */
@@ -184,9 +167,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals('0C097D9EC94C06363', $signature->getKeyId());
     }
 
-    // }}}
-    // {{{ testGetCreationDate()
-
     /**
      * @group accessors
      */
@@ -204,9 +184,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals(1221785858, $signature->getCreationDate());
     }
 
-    // }}}
-    // {{{ testGetExpirationDate()
-
     /**
      * @group accessors
      */
@@ -224,9 +201,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals(1421785858, $signature->getExpirationDate());
     }
 
-    // }}}
-    // {{{ testIsValid()
-
     /**
      * @group accessors
      */
@@ -256,9 +230,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertFalse($signature->isValid());
     }
 
-    // }}}
-    // {{{ testGetUserId()
-
     /**
      * @group accessors
      */
@@ -281,11 +252,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedUserId, $signature->getUserId());
     }
 
-    // }}}
-
-    // mutators
-    // {{{ testSetId()
-
     /**
      * @group mutators
      */
@@ -314,9 +280,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedSignature, $signature);
     }
 
-    // }}}
-    // {{{ testSetKeyFingerprint()
-
     /**
      * @group mutators
      */
@@ -346,9 +309,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedSignature, $signature);
     }
 
-    // }}}
-    // {{{ testSetKeyId()
-
     /**
      * @group mutators
      */
@@ -379,9 +339,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedSignature, $signature);
     }
 
-    // }}}
-    // {{{ testSetCreationDate()
-
     /**
      * @group mutators
      */
@@ -410,9 +367,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedSignature, $signature);
     }
 
-    // }}}
-    // {{{ testSetExpirationDate()
-
     /**
      * @group mutators
      */
@@ -441,9 +395,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedSignature, $signature);
     }
 
-    // }}}
-    // {{{ testSetValid()
-
     /**
      * @group mutators
      */
@@ -472,9 +423,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedSignature, $signature);
     }
 
-    // }}}
-    // {{{ testSetUserId()
-
     /**
      * @group accessors
      */
@@ -508,11 +456,6 @@ class SignatureTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedSignature, $signature);
     }
 
-    // }}}
-
-    // fluent interface
-    // {{{ testFluentInterface
-
     /**
      * @group fluent
      */
@@ -579,8 +522,4 @@ class SignatureTestCase extends Crypt_GPG_TestCase
             'Failed asserting fluent interface works for setUserId() method.'
         );
     }
-
-    // }}}
 }
-
-?>
